diff --git a/src/backend/executor/nodeModifyTable.c b/src/backend/executor/nodeModifyTable.c
index af7b26c..e9ae4e1 100644
--- a/src/backend/executor/nodeModifyTable.c
+++ b/src/backend/executor/nodeModifyTable.c
@@ -363,6 +363,7 @@ ExecInsert(ModifyTableState *mtstate,
 			uint32		specToken;
 			ItemPointerData conflictTid;
 			bool		specConflict;
+			bool		skipOne = true;
 
 			/*
 			 * Do a non-conclusive check for conflicts first.
@@ -378,7 +379,8 @@ ExecInsert(ModifyTableState *mtstate,
 			 */
 	vlock:
 			specConflict = false;
-			if (!ExecCheckIndexConstraints(slot, estate, &conflictTid,
+			if (!skipOne &&
+				!ExecCheckIndexConstraints(slot, estate, &conflictTid,
 										   arbiterIndexes))
 			{
 				/* committed conflict tuple found */
@@ -417,6 +419,13 @@ ExecInsert(ModifyTableState *mtstate,
 			}
 
 			/*
+			 * Having artificially rigged the implementation to assume no
+			 * conflict once, prevent that assumption from being made again in
+			 * any subsequent retry iteration
+			 */
+			skipOne = false;
+
+			/*
 			 * Before we start insertion proper, acquire our "speculative
 			 * insertion lock".  Others can use that to wait for us to decide
 			 * if we're going to go ahead with the insertion, instead of
